@@ -34,8 +34,8 @@ typedef enum {
     YELP_ERROR_UNKNOWN
 } YelpError;
 
+G_GNUC_INTERNAL
 GError *            yelp_error_copy               (GError *error);
-const gchar *       yelp_error_get_title          (GError *error);
 
 G_END_DECLS
 
