@@ -35,8 +35,6 @@ struct _YelpSettingsPrivate {
     gchar         colors[YELP_SETTINGS_NUM_COLORS][8];
     gchar        *setfonts[YELP_SETTINGS_NUM_FONTS];
     gchar        *fonts[YELP_SETTINGS_NUM_FONTS];
-    gchar        *icons[YELP_SETTINGS_NUM_ICONS];
-    gint          icon_size;
 
     GtkSettings  *gtk_settings;
     GtkIconTheme *gtk_icon_theme;
@@ -45,7 +43,6 @@ struct _YelpSettingsPrivate {
 
     gulong        gtk_theme_changed;
     gulong        gtk_font_changed;
-    gulong        icon_theme_changed;
 
     gboolean      show_text_cursor;
 
@@ -57,7 +54,6 @@ struct _YelpSettingsPrivate {
 enum {
     COLORS_CHANGED,
     FONTS_CHANGED,
-    ICONS_CHANGED,
     LAST_SIGNAL
 };
 static guint settings_signals[LAST_SIGNAL] = {0,};
@@ -71,8 +67,6 @@ enum {
   PROP_EDITOR_MODE
 };
 
-static const gchar *icon_names[YELP_SETTINGS_NUM_ICONS];
-
 G_DEFINE_TYPE_WITH_PRIVATE (YelpSettings, yelp_settings, G_TYPE_OBJECT)
 
 static void           yelp_settings_constructed  (GObject              *object);
@@ -94,17 +88,7 @@ static void           gtk_theme_changed          (GtkSettings          *gtk_sett
 static void           gtk_font_changed           (GtkSettings          *gtk_settings,
 						  GParamSpec           *pspec,
 					          YelpSettings         *settings);
-static void           icon_theme_changed         (GtkIconTheme         *theme,
-						  YelpSettings         *settings);
 
-static void           rgb_to_hsv                 (GdkRGBA  color,
-						  gdouble *h,
-						  gdouble *s,
-						  gdouble *v);
-static void           hsv_to_hex                 (gdouble  h,
-						  gdouble  s,
-						  gdouble  v,
-						  gchar    *str);
 
 /******************************************************************************/
 
@@ -112,35 +96,12 @@ static void
 yelp_settings_class_init (YelpSettingsClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
-    gint i;
 
     object_class->constructed  = yelp_settings_constructed;
     object_class->finalize = yelp_settings_finalize;
     object_class->get_property = yelp_settings_get_property;
     object_class->set_property = yelp_settings_set_property;
 
-    for (i = 0; i < YELP_SETTINGS_NUM_ICONS; i++) {
-	switch (i) {
-	case YELP_SETTINGS_ICON_BUG:
-	    icon_names[i] = "yelp-note-bug";
-	    break;
-	case YELP_SETTINGS_ICON_IMPORTANT:
-	    icon_names[i] = "yelp-note-important";
-	    break;
-	case YELP_SETTINGS_ICON_NOTE:
-	    icon_names[i] = "yelp-note";
-	    break;
-	case YELP_SETTINGS_ICON_TIP:
-	    icon_names[i] = "yelp-note-tip";
-	    break;
-	case YELP_SETTINGS_ICON_WARNING:
-	    icon_names[i] = "yelp-note-warning";
-	    break;
-	default:
-	    g_assert_not_reached ();
-	}
-    }
-
     g_object_class_install_property (object_class,
                                      PROP_GTK_SETTINGS,
                                      g_param_spec_object ("gtk-settings",
@@ -201,14 +162,6 @@ yelp_settings_class_init (YelpSettingsClass *klass)
 		      0, NULL, NULL,
 		      g_cclosure_marshal_VOID__VOID,
 		      G_TYPE_NONE, 0);
-
-    settings_signals[ICONS_CHANGED] =
-	g_signal_new ("icons-changed",
-		      G_OBJECT_CLASS_TYPE (klass),
-		      G_SIGNAL_RUN_LAST,
-		      0, NULL, NULL,
-		      g_cclosure_marshal_VOID__VOID,
-		      G_TYPE_NONE, 0);
 }
 
 static void
@@ -218,10 +171,7 @@ yelp_settings_init (YelpSettings *settings)
 
     settings->priv = yelp_settings_get_instance_private (settings);
     g_mutex_init (&settings->priv->mutex);
-    settings->priv->icon_size = 24;
 
-    for (i = 0; i < YELP_SETTINGS_NUM_ICONS; i++)
-	settings->priv->icons[i] = NULL;
     for (i = 0; i < YELP_SETTINGS_NUM_FONTS; i++) {
 	settings->priv->setfonts[i] = NULL;
 	settings->priv->fonts[i] = NULL;
@@ -530,11 +480,6 @@ yelp_settings_set_property (GObject      *object,
 	}
 	break;
     case PROP_GTK_ICON_THEME:
-	if (settings->priv->gtk_icon_theme) {
-	    g_signal_handler_disconnect (settings->priv->gtk_icon_theme,
-					 settings->priv->icon_theme_changed);
-	    g_object_unref (settings->priv->gtk_icon_theme);
-	}
 	settings->priv->gtk_icon_theme = g_value_get_object (value);
 	if (settings->priv->gtk_icon_theme != NULL) {
 	    gchar **search_path;
@@ -561,15 +506,6 @@ yelp_settings_set_property (GObject      *object,
                                                    DATADIR"/yelp/icons");
 	    g_strfreev (search_path);
 	    g_object_ref (settings->priv->gtk_icon_theme);
-	    settings->priv->icon_theme_changed =
-		g_signal_connect (settings->priv->gtk_icon_theme,
-				  "changed",
-				  (GCallback) icon_theme_changed,
-				  settings);
-	    icon_theme_changed (settings->priv->gtk_icon_theme, settings);
-	}
-	else {
-	    settings->priv->icon_theme_changed = 0;
 	}
 	break;
     case PROP_FONT_ADJUSTMENT:
@@ -665,20 +601,8 @@ const gchar*
 yelp_settings_get_color_param (YelpSettingsColor color)
 {
     static const gchar *params[YELP_SETTINGS_NUM_COLORS] = {
-	"color.background",
-	"color.text",
-	"color.text_light",
-	"color.link",
-	"color.link_visted",
-	"color.gray_background",
-	"color.dark_background",
-	"color.gray_border",
-	"color.blue_background",
-	"color.blue_border",
-	"color.red_background",
-	"color.red_border",
-	"color.yellow_background",
-	"color.yellow_border"
+        "color.bg",
+        "color.fg"
     };
     g_return_val_if_fail (color < YELP_SETTINGS_NUM_COLORS, NULL);
     return params[color];
@@ -814,77 +738,6 @@ yelp_settings_set_font_adjustment (YelpSettings *settings,
 
 /******************************************************************************/
 
-gint
-yelp_settings_get_icon_size (YelpSettings *settings)
-{
-    return settings->priv->icon_size;
-}
-
-void
-yelp_settings_set_icon_size (YelpSettings *settings,
-			     gint          size)
-{
-    settings->priv->icon_size = size;
-    if (settings->priv->gtk_icon_theme != NULL)
-	icon_theme_changed (settings->priv->gtk_icon_theme, settings);
-}
-
-gchar *
-yelp_settings_get_icon (YelpSettings     *settings,
-			YelpSettingsIcon  icon)
-{
-    gchar *ret;
-    g_return_val_if_fail (icon < YELP_SETTINGS_NUM_ICONS, NULL);
-
-    g_mutex_lock (&settings->priv->mutex);
-    ret = g_strdup (settings->priv->icons[icon]);
-    g_mutex_unlock (&settings->priv->mutex);
-
-    return ret;
-}
-
-void
-yelp_settings_set_icons (YelpSettings     *settings,
-			 YelpSettingsIcon  first_icon,
-			 ...)
-{
-    YelpSettingsIcon icon;
-    va_list args;
-
-    g_mutex_lock (&settings->priv->mutex);
-    va_start (args, first_icon);
-
-    icon = first_icon;
-    while ((gint) icon >= 0) {
-	gchar *filename = va_arg (args, gchar *);
-	if (settings->priv->icons[icon] != NULL)
-	    g_free (settings->priv->icons[icon]);
-	settings->priv->icons[icon] = g_filename_to_uri (filename, NULL, NULL);
-	icon = va_arg (args, YelpSettingsIcon);
-    }
-
-    va_end (args);
-    g_mutex_unlock (&settings->priv->mutex);
-
-    g_signal_emit (settings, settings_signals[ICONS_CHANGED], 0);
-}
-
-const gchar *
-yelp_settings_get_icon_param (YelpSettingsIcon icon)
-{
-    static const gchar *params[YELP_SETTINGS_NUM_ICONS] = {
-	"icons.note.bug",
-	"icons.note.important",
-	"icons.note",
-	"icons.note.tip",
-	"icons.note.warning"
-    };
-    g_return_val_if_fail (icon < YELP_SETTINGS_NUM_ICONS, NULL);
-    return params[icon];
-}
-
-/******************************************************************************/
-
 gboolean
 yelp_settings_get_show_text_cursor (YelpSettings *settings)
 {
@@ -936,7 +789,7 @@ yelp_settings_get_all_params (YelpSettings *settings,
     GList *envs, *envi;
 
     params = g_new0 (gchar *,
-                     (2*YELP_SETTINGS_NUM_COLORS) + (2*YELP_SETTINGS_NUM_ICONS) + extra + 9);
+                     (2*YELP_SETTINGS_NUM_COLORS) + extra + 7);
 
     for (i = 0; i < YELP_SETTINGS_NUM_COLORS; i++) {
         gchar *val;
@@ -946,17 +799,7 @@ yelp_settings_get_all_params (YelpSettings *settings,
         params[ix + 1] = g_strdup_printf ("\"%s\"", val);
         g_free (val);
     }
-    for (i = 0; i < YELP_SETTINGS_NUM_ICONS; i++) {
-        gchar *val;
-        ix = 2 * (YELP_SETTINGS_NUM_COLORS + i);
-        params[ix] = g_strdup (yelp_settings_get_icon_param (i));
-        val = yelp_settings_get_icon (settings, i);
-        params[ix + 1] = g_strdup_printf ("\"%s\"", val);
-        g_free (val);
-    }
-    ix = 2 * (YELP_SETTINGS_NUM_COLORS + YELP_SETTINGS_NUM_ICONS);
-    params[ix++] = g_strdup ("icons.size.note");
-    params[ix++] = g_strdup_printf ("%i", yelp_settings_get_icon_size (settings));
+    ix = 2 * YELP_SETTINGS_NUM_COLORS;
     params[ix++] = g_strdup ("yelp.editor_mode");
     if (settings->priv->editor_mode)
         params[ix++] = g_strdup ("true()");
@@ -996,102 +839,26 @@ gtk_theme_changed (GtkSettings  *gtk_settings,
 		   GParamSpec   *pspec,
 		   YelpSettings *settings)
 {
-    GtkStyleContext *context, *linkcontext;
-    GtkWidget *tmpwin, *tmpbox, *tmpview, *tmplink;
-    GdkRGBA base, text, link;
-    gdouble    base_h, base_s, base_v;
-    gdouble    text_h, text_s, text_v;
+    GtkStyleContext *context;
+    GdkRGBA base, text;
 
     g_mutex_lock (&settings->priv->mutex);
 
-    tmpwin = gtk_offscreen_window_new ();
-    tmpbox = gtk_grid_new ();
-    tmpview = gtk_text_view_new ();
-    tmplink = gtk_link_button_new ("http://projectmallard.org/");
-    gtk_container_add (GTK_CONTAINER (tmpwin), tmpbox);
-    gtk_container_add (GTK_CONTAINER (tmpbox), tmpview);
-    gtk_container_add (GTK_CONTAINER (tmpbox), tmplink);
-    gtk_widget_show_all (tmpwin);
+    context = gtk_style_context_new ();
 
-    context = gtk_widget_get_style_context (tmpview);
-    gtk_style_context_save (context);
+    if ( gtk_style_context_lookup_color(context, "theme_base_color", &base) &&
+         gtk_style_context_lookup_color(context, "theme_text_color", &text) ) {
+        g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_BASE], 8, "#%02X%02X%02X",
+                    (guint) (base.red * 255), (guint) (base.green * 255), (guint) (base.blue * 255));
+        g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_TEXT], 8, "#%02X%02X%02X",
+                    (guint) (text.red * 255), (guint) (text.green * 255), (guint) (text.blue * 255));
+    }
+    else {
+        g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_BASE], 8, "#FFFFFF");
+        g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_TEXT], 8, "#000000");
+    }
 
-    gtk_style_context_set_state (context, GTK_STATE_FLAG_NORMAL);
-    gtk_style_context_add_class (context, GTK_STYLE_CLASS_VIEW);
-    gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &text);
-    gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &base);
-
-    gtk_style_context_restore (context);
-
-    rgb_to_hsv (text, &text_h, &text_s, &text_v);
-    rgb_to_hsv (base, &base_h, &base_s, &base_v);
-
-    /* YELP_SETTINGS_COLOR_BASE */
-    g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_BASE], 8, "#%02X%02X%02X",
-                (guint) (base.red * 255), (guint) (base.green * 255), (guint) (base.blue * 255));
-
-    /* YELP_SETTINGS_COLOR_TEXT */
-    g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_TEXT], 8, "#%02X%02X%02X",
-                (guint) (text.red * 255), (guint) (text.green * 255), (guint) (text.blue * 255));
-
-    linkcontext = gtk_widget_get_style_context (tmplink);
-    gtk_style_context_save (linkcontext);
-
-    /* YELP_SETTINGS_COLOR_LINK */
-    gtk_style_context_set_state (linkcontext, GTK_STATE_FLAG_LINK);
-    gtk_style_context_get_color (linkcontext, GTK_STATE_FLAG_LINK, &link);
-    g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_LINK], 8, "#%02X%02X%02X",
-                (guint) (link.red * 255), (guint) (link.green * 255), (guint) (link.blue * 255));
-
-    /* YELP_SETTINGS_COLOR_LINK_VISITED */
-    gtk_style_context_set_state (linkcontext, GTK_STATE_FLAG_VISITED);
-    gtk_style_context_get_color (linkcontext, GTK_STATE_FLAG_VISITED, &link);
-    g_snprintf (settings->priv->colors[YELP_SETTINGS_COLOR_LINK_VISITED], 8, "#%02X%02X%02X",
-                (guint) (link.red * 255), (guint) (link.green * 255), (guint) (link.blue * 255));
-
-
-    gtk_style_context_restore (linkcontext);
-
-    /* YELP_SETTINGS_COLOR_TEXT_LIGHT */
-    hsv_to_hex (text_h, text_s, text_v - ((text_v - base_v) * 0.25),
-                settings->priv->colors[YELP_SETTINGS_COLOR_TEXT_LIGHT]);
-
-    /* YELP_SETTINGS_COLOR_GRAY */
-    hsv_to_hex (base_h, base_s,
-                base_v - ((base_v - text_v) * 0.05),
-                settings->priv->colors[YELP_SETTINGS_COLOR_GRAY_BASE]);
-    hsv_to_hex (base_h, base_s,
-                base_v - ((base_v - text_v) * 0.1),
-                settings->priv->colors[YELP_SETTINGS_COLOR_DARK_BASE]);
-    hsv_to_hex (base_h, base_s,
-                base_v - ((base_v - text_v) * 0.26),
-                settings->priv->colors[YELP_SETTINGS_COLOR_GRAY_BORDER]);
-
-    /* YELP_SETTINGS_COLOR_BLUE */
-    hsv_to_hex (211, 0.1,
-                base_v - ((base_v - text_v) * 0.01),
-                settings->priv->colors[YELP_SETTINGS_COLOR_BLUE_BASE]);
-    hsv_to_hex (211, 0.45,
-                base_v - ((base_v - text_v) * 0.19),
-                settings->priv->colors[YELP_SETTINGS_COLOR_BLUE_BORDER]);
-
-    /* YELP_SETTINGS_COLOR_RED */
-    hsv_to_hex (0, 0.13,
-                base_v - ((base_v - text_v) * 0.01),
-                settings->priv->colors[YELP_SETTINGS_COLOR_RED_BASE]);
-    hsv_to_hex (0, 0.83,
-                base_v - ((base_v - text_v) * 0.06),
-                settings->priv->colors[YELP_SETTINGS_COLOR_RED_BORDER]);
-
-    /* YELP_SETTINGS_COLOR_YELLOW */
-    hsv_to_hex (60, 0.25,
-                base_v - ((base_v - text_v) * 0.01),
-                settings->priv->colors[YELP_SETTINGS_COLOR_YELLOW_BASE]);
-    hsv_to_hex (60, 1.0,
-                base_v - ((base_v - text_v) * 0.07),
-                settings->priv->colors[YELP_SETTINGS_COLOR_YELLOW_BORDER]);
-
-    gtk_widget_destroy (tmpwin);
+    g_object_unref (context);
 
     g_mutex_unlock (&settings->priv->mutex);
 
@@ -1128,37 +895,6 @@ gtk_font_changed (GtkSettings  *gtk_settings,
     g_signal_emit (settings, settings_signals[FONTS_CHANGED], 0);
 }
 
-static void
-icon_theme_changed (GtkIconTheme *theme,
-		    YelpSettings *settings)
-{
-    GtkIconInfo *info;
-    gint i;
-
-    g_mutex_lock (&settings->priv->mutex);
-
-    for (i = 0; i < YELP_SETTINGS_NUM_ICONS; i++) {
-	if (settings->priv->icons[i] != NULL)
-	    g_free (settings->priv->icons[i]);
-	info = gtk_icon_theme_lookup_icon (theme,
-					   icon_names[i],
-					   settings->priv->icon_size,
-					   GTK_ICON_LOOKUP_NO_SVG);
-	if (info != NULL) {
-	    settings->priv->icons[i] = g_filename_to_uri (gtk_icon_info_get_filename (info),
-                                                          NULL, NULL);
-	    g_object_unref (info);
-	}
-	else {
-	    settings->priv->icons[i] = NULL;
-	}
-    }
-
-    g_mutex_unlock (&settings->priv->mutex);
-
-    g_signal_emit (settings, settings_signals[ICONS_CHANGED], 0);
-}
-
 gint
 yelp_settings_cmp_icons (const gchar *icon1,
                          const gchar *icon2)
@@ -1193,75 +929,3 @@ yelp_settings_cmp_icons (const gchar *icon1,
     else
         return strcmp (icon1, icon2);
 }
-
-/******************************************************************************/
-
-static void
-rgb_to_hsv (GdkRGBA color, gdouble *h, gdouble *s, gdouble *v)
-{
-    gdouble min, max, delta;
-
-    max = (color.red > color.green) ? color.red : color.green;
-    max = (max > color.blue) ? max : color.blue;
-    min = (color.red < color.green) ? color.red : color.green;
-    min = (min < color.blue) ? min : color.blue;
-
-    delta = max - min;
-
-    *v = max;
-    *s = 0;
-    *h = 0;
-
-    if (max != min) {
-	*s = delta / *v;
-
-	if (color.red == max)
-	    *h = (color.green - color.blue) / delta;
-	else if (color.green == max)
-	    *h = 2 + (color.blue - color.red) / delta;
-	else if (color.blue == max)
-	    *h = 4 + (color.red - color.green) / delta;
-
-	*h *= 60;
-	if (*h < 0.0)
-	    *h += 360;
-    }
-}
-
-static void
-hsv_to_hex (gdouble h, gdouble s, gdouble v, gchar *str)
-{
-    gint hue;
-    gdouble m1, m2, m3;
-    gdouble r, g, b;
-    guint red, green, blue;
-
-    h /= 60;
-    hue = (int) h;
-    m1 = v * (1 - s);
-    m2 = v * (1 - s * (h - hue));
-    m3 = v * (1 - s * (-h + hue + 1));
-
-    r = g = b = v;
-    switch (hue) {
-    case 0:
-        b = m1; g = m3; break;
-    case 1:
-        b = m1; r = m2; break;
-    case 2:
-        r = m1; b = m3; break;
-    case 3:
-        r = m1; g = m2; break;
-    case 4:
-        g = m1; r = m3; break;
-    case 5:
-        g = m1; b = m2; break;
-    default:
-        g_assert_not_reached (); break;
-    }
-
-    red = r * 255;
-    green = g * 255;
-    blue = b * 255;
-    g_snprintf (str, 8, "#%02X%02X%02X", red, green, blue);
-}
